import warnings
warnings.filterwarnings("ignore")
def dynamic_rename(df):
    df_col=[]
    for i in df.columns:
        df_col.append(i)
    for i in range(len(df_col)):
        print("current columns Name:" ,df_col[i])
        new_col_name=input('Kindly Enter renamed column name :')
        df=df.withColumnRenamed(df_col[i],new_col_name)
        print('column renamed to sucessfully to',new_col_name,'\n')
    return df



from setuptools import setup

setup(name='dynamic_rename',
        version='0.0.5',
        description='Column rename  in pyspark dataframe',
        packages=['dynamic_rename'],
        author_email='ranjitmaity95@gmail.com',
        zip_safe=False,
        long_description_content_type="text/markdown",
        long_description=open('README.md').read(),
        )